@@ -4,7 +4,6 @@ from .basic_types import (
     AutorunDecorator,
     AutorunOptions,
     AutorunReturnType,
-    AutorunType,
     BaseAction,
     BaseCombineReducerState,
     BaseEvent,
@@ -24,6 +23,8 @@ from .basic_types import (
     ReducerResult,
     ReducerType,
     Scheduler,
+    ViewDecorator,
+    ViewReturnType,
     is_complete_reducer_result,
     is_state_reducer_result,
 )
@@ -34,9 +35,13 @@ __all__ = (
     'AutorunDecorator',
     'AutorunOptions',
     'AutorunReturnType',
-    'AutorunType',
     'BaseAction',
+    'BaseCombineReducerState',
     'BaseEvent',
+    'CombineReducerAction',
+    'CombineReducerInitAction',
+    'CombineReducerRegisterAction',
+    'CombineReducerUnregisterAction',
     'CompleteReducerResult',
     'CreateStoreOptions',
     'Dispatch',
@@ -49,13 +54,10 @@ __all__ = (
     'ReducerResult',
     'ReducerType',
     'Scheduler',
+    'ViewDecorator',
+    'ViewReturnType',
     'is_complete_reducer_result',
     'is_state_reducer_result',
-    'BaseCombineReducerState',
-    'CombineReducerAction',
-    'CombineReducerInitAction',
-    'CombineReducerRegisterAction',
-    'CombineReducerUnregisterAction',
     'combine_reducers',
     'Store',
 )
